#include "Response.h"

/**
 * Konstruktor Response() vytvori podtriedy, ktore budu potrebne na vykonanie odozvy na situaciu vzniknutu na ihrisku.
 * @param team - Tim agenta.
 * @param id - Cislo agenta.
 * @param playGroundLength - Dlzka ihriska.
 * @param playGroundWidth - Sirka ihriska.
 * @param goalWidth - Sirka brany.
 * @param goalHeight - Vyska brany.
 */

Response::Response(char *team, int id, float playGroundLength, float playGroundWidth, float goalWidth, float goalHeight)
{
	perceptorSet = new PerceptorSet();
	behaviour = new Behaviour(team, id, playGroundLength, playGroundWidth, goalWidth, goalHeight);
	effectorSet = new EffectorSet();
}

/**
 * Metoda nextStep() pomocou vytvorenych podtried umozni vykonat odozvu na situaciu vzniknutu na ihrisku.
 * @param receivingMessage - Prijata sprava, ktora popisuje situaciu vzniknutu na ihrisku pomocou perceptorov.
 * @param sendingMessage - Vystupna posielana sprava, ktorou sa popisuje vykonanie odozvy na situaciu vzniknutu na ihrisku pomocou efektorov.
 * @param sendingMessageSize - Maximalna dlzka posielanej spravy.
 */

void Response::nextStep(char *receivingMessage, char *sendingMessage, int sendingMessageSize)
{
	perceptorSet->decompose(receivingMessage);
	behaviour->nextStep(perceptorSet, effectorSet);
	effectorSet->compose(sendingMessage, sendingMessageSize);
}

/**
 * Destruktor ~Response() zrusi podtriedy, ktore boli potrebne na vykonanie odozvy na situaciu vzniknutu na ihrisku.
 */

Response::~Response()
{
	delete effectorSet;
	delete behaviour;
	delete perceptorSet;
}
