#ifndef ME_H_
#define ME_H_

#include "../../EffectorSet.h"
#include "../../PerceptorSet.h"
#include "me/ForceResistance2.h"
#include "me/Hear2.h"
#include "me/HingeJoint2.h"
#include "me/NextState.h"

#define HEAD1 0
#define HEAD2 1
#define RIGHTARM1 2
#define RIGHTARM2 3
#define RIGHTARM3 4
#define RIGHTARM4 5
#define RIGHTLEG1 6
#define RIGHTLEG2 7
#define RIGHTLEG3 8
#define RIGHTLEG4 9
#define RIGHTLEG5 10
#define RIGHTLEG6 11
#define LEFTARM1 12
#define LEFTARM2 13
#define LEFTARM3 14
#define LEFTARM4 15
#define LEFTLEG1 16
#define LEFTLEG2 17
#define LEFTLEG3 18
#define LEFTLEG4 19
#define LEFTLEG5 20
#define LEFTLEG6 21

/**
 * Trieda Me predstavuje mna (agenta) na ihrisku.
 * @author Michal Kvetan
 * @version 8.12.11
 */

class Me
{
private:
	char team[100];
	int id;
	char side[100];
	float playGroundLength;
	float playGroundWidth;
	float goalWidth;
	float goalHeight;
	float *f1r;
	float *g1r;
	float *g2r;
	float *f2r;
	float *f2l;
	float *g2l;
	float *g1l;
	float *f1l;
	float position[3];
	float rotationMatrix[3][3];
	float beam[3];
	bool beamChanged;
	HingeJoint2 *hingeJoint2;
	int forceResistance2Count;
	ForceResistance2 *forceResistance2;
	int hear2Count;
	Hear2 *hear2;
	char say[100];
	bool sayChanged;
	NextState *nextState;
	void getPosition(float object0[3], float distanceFromObject0, float object1[3], float distanceFromObject1, float object2[3], float distanceFromObject2, float position0[2], float position1[2], float position2[2]);
	void getObject(float distance, float angle1, float angle2, float object[3]);
	void getSolution(float a00, float a01, float a02, float b0, float a10, float a11, float a12, float b1, float a20, float a21, float a22, float b2, float solution[3]);
	void getRotationMatrix(float object00[3], float object01[3], float object10[3], float object11[3], float object20[3], float object21[3], float rotationMatrix[3][3]);
public:
	Me(char *team, int id, float playGroundLength, float playGroundWidth, float goalWidth, float goalHeight, float f1r[3], float g1r[3], float g2r[3], float f2r[3], float f2l[3], float g2l[3], float g1l[3], float f1l[3]);
	void transform(PerceptorSet *perceptorSet);
	void reverseTransform(EffectorSet *effectorSet);
	char *getTeam();
	int getId();
	char *getSide();
	float *getPosition();
	float (*getRotationMatrix())[3];
	void setPositionAndRotation(float x, float y, float rotation);
	HingeJoint2 *getHingeJoint2(int index);
	int getForceResistance2Count();
	ForceResistance2 *getForceResistance2(int index);
	int getHear2Count();
	Hear2 *getHear2(int index);
	void setSay(char *message);
	NextState *getNextState();
	virtual ~Me();
};

#endif /* ME_H_ */
