#include "Player.h"
#include <math.h>
#include <string.h>

/**
 * Konstruktor Player() inicializuje prvky, ktore budu potrebne na pracu s hracom na ihrisku.
 */

Player::Player()
{
	team[0] = '\0';
	id = 0;
	position[0] = 340282346638528860000000000000000000000.0f;
	position[1] = 340282346638528860000000000000000000000.0f;
	position[2] = 340282346638528860000000000000000000000.0f;
}

/**
 * Metoda transform() transformuje data.
 * @param team - Tim hraca na ihrisku.
 * @param id - Cislo hraca na ihrisku.
 * @param myPosition - Pozicia agenta na ihrisku.
 * @param myRotationMatrix - Rotacna matica agenta na ihrisku.
 * @param distance - Vzdialenost agenta od hraca.
 * @param angle1 - Polarny uhol medzi polarnou osou a smerom vektora vzdialenosti agenta od hraca.
 * @param angle2 - Azimutalny uhol medzi priemetom vektora vzdialenosti agenta od hraca do roviny kolmej na polarnu os a zvolenou osou v tejto rovine.
 */

void Player::transform(char *team, int id, float myPosition[3], float myRotationMatrix[3][3], float distance, float angle1, float angle2)
{
#ifdef WIN32
	strcpy_s(this->team, team);
#else
	strcpy(this->team, team);
#endif
	this->id = id;
	if (myPosition[0] != 340282346638528860000000000000000000000.0f || myPosition[1] != 340282346638528860000000000000000000000.0f || myPosition[2] != 340282346638528860000000000000000000000.0f || myRotationMatrix[0][0] != 340282346638528860000000000000000000000.0f || myRotationMatrix[0][1] != 340282346638528860000000000000000000000.0f || myRotationMatrix[0][2] != 340282346638528860000000000000000000000.0f || myRotationMatrix[1][0] != 340282346638528860000000000000000000000.0f || myRotationMatrix[1][1] != 340282346638528860000000000000000000000.0f || myRotationMatrix[1][2] != 340282346638528860000000000000000000000.0f || myRotationMatrix[2][0] != 340282346638528860000000000000000000000.0f || myRotationMatrix[2][1] != 340282346638528860000000000000000000000.0f || myRotationMatrix[2][2] != 340282346638528860000000000000000000000.0f)
	{
		float radAngle1 = angle1 / 57.295780181884765625f;
		float radAngle2 = angle2 / 57.295780181884765625f;
		float distance2 = cos(radAngle2) * distance;
		float object[3] = {cos(radAngle1) * distance2, sin(radAngle1) * distance2, sin(radAngle2) * distance};
		position[0] = myPosition[0] + myRotationMatrix[0][0] * object[0] + myRotationMatrix[0][1] * object[1] + myRotationMatrix[0][2] * object[2];
		position[1] = myPosition[1] + myRotationMatrix[1][0] * object[0] + myRotationMatrix[1][1] * object[1] + myRotationMatrix[1][2] * object[2];
		position[2] = myPosition[2] + myRotationMatrix[2][0] * object[0] + myRotationMatrix[2][1] * object[1] + myRotationMatrix[2][2] * object[2];
	}
	else
	{
		position[0] = 340282346638528860000000000000000000000.0f;
		position[1] = 340282346638528860000000000000000000000.0f;
		position[2] = 340282346638528860000000000000000000000.0f;
	}
}

/**
 * Metoda getTeam() vrati tim hraca na ihrisku.
 * @return Tim hraca na ihrisku.
 */

char *Player::getTeam()
{
	return team;
}

/**
 * Metoda getId() vrati cislo hraca na ihrisku.
 * @return Cislo hraca na ihrisku.
 */

int Player::getId()
{
	return id;
}

/**
 * Metoda getPosition() vrati poziciu hraca na ihrisku.
 * @return Pozicia hraca na ihrisku (Ukazovatel na jednorozmerne pole s 3 hodnotami - suradnicami hraca na ihrisku). Ak pozicia hraca na ihrisku nie je znama, tak sa vrati ukazovatel na jednorozmerne pole s 3 hodnotami 340282346638528860000000000000000000000.0f - co znamena neznamu poziciu hraca na ihrisku.
 */

float *Player::getPosition()
{
	return position;
}
