#include "GS.h"
#include <iostream>
#include <string.h>

using namespace std;

/**
 * Konstruktor GS() vytvori podtriedy, ktore budu potrebne na rozlozenie casti prijatej spravy, ktora obsahuje GS_perceptor.
 */

GS::GS()
{
	t = new T();
	pm = new Pm();
	unumCount = 0;
	unum = new Unum[1]();
	teamCount = 0;
	team = new Team[1]();
}

/**
 * Metoda decompose() rozlozi na prvky podtried cast prijatej spravy, ktora obsahuje GS_perceptor.
 * @param receivingMessage - Cast prijatej spravy, ktora obsahuje GS_perceptor.
 * @return Dlzka casti prijatej spravy, ktora obsahuje GS_perceptor.
 */

int GS::decompose(char *receivingMessage)
{
	unumCount = 0;
	teamCount = 0;
	int i = 4;
	while (receivingMessage[i] != ')')
	{
		if (receivingMessage[i] == '(')
		{
			char *receivingMessage2 = receivingMessage + i;
			char *receivingMessage3 = receivingMessage2 + 1;
			if (strncmp(receivingMessage3, "t ", 2) == 0)
			{
				i += t->decompose(receivingMessage2);
			}
			else if (strncmp(receivingMessage3, "pm ", 3) == 0)
			{
				i += pm->decompose(receivingMessage2);
			}
			else if (strncmp(receivingMessage3, "unum ", 5) == 0)
			{
				i += unum[unumCount].decompose(receivingMessage2);
				unumCount ++;
			}
			else if (strncmp(receivingMessage3, "team ", 5) == 0)
			{
				i += team[teamCount].decompose(receivingMessage2);
				teamCount ++;
			}
			else
			{
				int j = 1;
				int k = 1;
				do
				{
					switch (receivingMessage2[j])
					{
						case '(':
							k ++;
							break;
						case ')':
							k --;
							break;
					}
					j ++;
				}
				while (k > 0);
				i += j;
				char *perceptor = new char[j + 1];
				memcpy(perceptor, receivingMessage2, j);
				perceptor[j] = '\0';
				cerr << "Agent nepozna \"GS\" perceptor: \"" << perceptor << "\"." << endl;
				delete[] perceptor;
			}
		}
		else
		{
			i ++;
		}
	}
	return i + 1;
}

/**
 * Metoda getT() vrati ukazovatel na t perceptor.
 * @return Ukazovatel na t perceptor.
 */

T *GS::getT()
{
	return t;
}

/**
 * Metoda getPm() vrati ukazovatel na pm perceptor.
 * @return Ukazovatel na pm perceptor.
 */

Pm *GS::getPm()
{
	return pm;
}

/**
 * Metoda getUnumCount() vrati pocet unum perceptorov, ktore boli obsiahnute v prijatej sprave.
 * @return Pocet unum perceptorov.
 */

int GS::getUnumCount()
{
	return unumCount;
}

/**
 * Metoda getUnum() vrati ukazovatel na pozadovany unum perceptor.
 * @param index - Cislo pozadovaneho unum perceptoru.
 * @return Ukazovatel na pozadovany unum perceptor.
 */

Unum *GS::getUnum(int index)
{
	return &unum[index];
}

/**
 * Metoda getTeamCount() vrati pocet team perceptorov, ktore boli obsiahnute v prijatej sprave.
 * @return Pocet team perceptorov.
 */

int GS::getTeamCount()
{
	return teamCount;
}

/**
 * Metoda getTeam() vrati ukazovatel na team perceptor.
 * @param index - Cislo pozadovaneho team perceptoru.
 * @return Ukazovatel na team perceptor.
 */

Team *GS::getTeam(int index)
{
	return &team[index];
}

/**
 * Desruktor ~GS() zrusi podtriedy, ktore boli potrebne na rozlozenie casti prijatej spravy, ktora obsahovala GS_perceptor.
 */

GS::~GS()
{
	delete[] team;
	delete[] unum;
	delete pm;
	delete t;
}
